@@ -11,12 +11,14 @@ module WebConsole
   autoload :ExceptionMapper
   autoload :Session
   autoload :Injector
+  autoload :Interceptor
   autoload :Request
   autoload :WhinyRequest
-  autoload :Whitelist
+  autoload :Permissions
   autoload :Template
   autoload :Middleware
   autoload :Context
+  autoload :SourceLocation
 
   autoload_at "web_console/errors" do
     autoload :Error
